#!/usr/bin/php -q
<?php

/* do NOT run this script through a web browser */
if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
	die("<br><strong>This script is only meant to run at the command line.</strong>");
} 
 
/* We are not talking to the browser */
$no_http_headers = true;

include(dirname(__FILE__)."/../include/global.php");
include_once($config["base_path"]."/lib/template.php");
include_once($config["base_path"]."/lib/data_query.php");

/* function to get graph_templates_graph record */
function getGrphTempGrph($local_graph_id) {

	$gtg = db_fetch_row("SELECT *
		FROM graph_templates_graph
		WHERE local_graph_id = " . $local_graph_id);

	return $gtg;
}

/* function to get data_template_rrd records from a data source */
function getDataTempRRD($data_source_id) {

	$result = array();
	$data_temp_rrd = db_fetch_assoc("SELECT data_source_name, id
				FROM data_template_rrd
				WHERE local_data_id = " . $data_source_id);

	/* it returns the following format: Array([data_source_name] => id) */
	foreach ($data_temp_rrd as $item) {
		$result[$item['data_source_name']] = $item['id'];
	}

	return $result;
}

/* function to get the data_source_name from a data_template_rrd */
function getDSName($data_temp_id) {

	$dsname = db_fetch_cell("SELECT data_source_name
		FROM data_template_rrd
		WHERE id = " . $data_temp_id);

	return $dsname;
}

function display_help() {

	echo "Add Extra Graph\n\n";
	echo "A command line utility to add an extra graph to a Data Source, using a graph template \n\n";
	echo "Add Extra Graph usage: php -q add_extragraph.php --host-id=<host_id> --graph-template-id=<graph_template_id> --data-source-id=<data_source_id> [--title=<string>]\n";
	echo "Required:\n";
	echo "    --host-id		host ID.\n";
	echo "    --graph-template-id	Graph Template ID.\n";
	echo "    --data-source-id    	Data Source ID.\n";
	echo "Optional:\n";
	echo "    --title		Title for the graph.\n";

}



/* process calling arguments*/
$parms = $_SERVER["argv"];
array_shift($parms);

if (!sizeof($parms)) {
	display_help();
	exit(0);
}

/* defaults */
$host_id = "";
$graph_template_id = "";
$data_source_id = "";
$title = "No Title";



foreach($parms as $parameter) {
	@list($arg, $value) = @explode("=", $parameter);
		
	switch ($arg) {
		case "--host-id":
			if(!sizeof($value)){
				echo "ERROR: No host ID supplied.\n";
				display_help();
				exit(1);
			}
			$host_id = $value;
			break;
		case "--graph-template-id":
			if(!sizeof($value)){
				echo "ERROR: No Graph Template ID supplied.\n";
				display_help();
				exit(1);
			}
			$graph_template_id = $value;
			break;
		case "--data-source-id":
			if(!sizeof($value)){
				echo "ERROR: No Data Source ID supplied.\n";
				display_help();
				exit(1);
			}
			$data_source_id = $value;
			break;
		case "--title":			
			$title = $value;
			break;
		default:
			echo "ERROR: Invalid Argument: ($arg)\n\n";
			display_help();
			exit(1);
	}
}

/* if we have al vars */
if ($host_id && $graph_template_id && $title && $data_source_id) {

	/* new graph data */	
	$graph["id"] = 0; /* 0 -> create a new graph */
	$graph["graph_template_id"] = $graph_template_id;
	$graph["host_id"] = $host_id;

	$local_graph_id = sql_save($graph, "graph_local"); /* save graph */

	change_graph_template($local_graph_id, $graph_template_id, true); /* this creates graph_templates_graph and graph_templates_item records */

	/* get graph_templates_graph record */
	$gtg = getGrphTempGrph($local_graph_id);

	/* update graph_templates_graph record and save it */
	$gtg['title'] = $title;
	sql_save($gtg, "graph_templates_graph");
	
	/* inputs */
	$input_list = db_fetch_assoc("select id,column_name from graph_template_input where graph_template_id=$graph_template_id");
	$data_template_rrd = getDataTempRRD($data_source_id);

	if (sizeof($input_list) > 0) {
		foreach ($input_list as $input) {
			/* we need to find out which graph items will be affected by saving this particular item */
			$item_list = db_fetch_assoc("select
				graph_templates_item.id, graph_templates_item.task_item_id
				from (graph_template_input_defs,graph_templates_item)
				where graph_template_input_defs.graph_template_item_id=graph_templates_item.local_graph_template_item_id
				and graph_templates_item.local_graph_id=" . $local_graph_id . "
				and graph_template_input_defs.graph_template_input_id=" . $input["id"]);
		
			/* loop through each item affected and update column data */
			if (sizeof($item_list) > 0) {
				foreach ($item_list as $item) {
					db_execute("update graph_templates_item set " . $input["column_name"] . "=" . $data_template_rrd[getDSName($item['task_item_id'])] . " where id=" . $item["id"]);				
				}
			}
		}
	}

	/* update the title cache */
	update_graph_title_cache($local_graph_id);

	/* update data query cache */
	update_graph_data_query_cache($local_graph_id);

	exit(0);

} else {
	echo "ERROR: Not enough arguments.\n\n";
	exit(1);
}

?>
